##  Designing a Survey From Scratch
In the Design tab, you can easily design the survey form by dragging and dropping different types of input fields from the left pane onto the survey editor. There are three primary categories of input fields available for designing survey questions: Fact sheet fields, basic fields, and advanced fields.
